Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1283)

Unified Diff: device/devices_app/usb/device_manager_impl_unittest.cc

Issue 1265833005: Get all the UsbConfigDescriptor for the device configuration (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: use const auto Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/devices_app/usb/device_manager_impl_unittest.cc
diff --git a/device/devices_app/usb/device_manager_impl_unittest.cc b/device/devices_app/usb/device_manager_impl_unittest.cc
index 4b0a9bf0267b56e8cca1a551d87ec1ba5eb4bad3..e26b9aa51b8ae4afcd014cc711e37042d2582384 100644
--- a/device/devices_app/usb/device_manager_impl_unittest.cc
+++ b/device/devices_app/usb/device_manager_impl_unittest.cc
@@ -151,10 +151,10 @@ TEST_F(USBDeviceManagerImplTest, GetDevices) {
guids.insert(device1->guid());
guids.insert(device2->guid());
- // One call to GetConfiguration for each device during enumeration.
- EXPECT_CALL(*device0.get(), GetConfiguration());
- EXPECT_CALL(*device1.get(), GetConfiguration());
- EXPECT_CALL(*device2.get(), GetConfiguration());
+ // One call to GetActiveConfiguration for each device during enumeration.
+ EXPECT_CALL(*device0.get(), GetActiveConfiguration());
+ EXPECT_CALL(*device1.get(), GetActiveConfiguration());
+ EXPECT_CALL(*device2.get(), GetActiveConfiguration());
base::RunLoop loop;
device_manager->GetDevices(
@@ -180,7 +180,7 @@ TEST_F(USBDeviceManagerImplTest, OpenDevice) {
.WillByDefault(Invoke(&open_callback, &MockOpenCallback::Open));
// Should be called on the mock as a result of GetDeviceInfo() below.
- EXPECT_CALL(*mock_device.get(), GetConfiguration());
+ EXPECT_CALL(*mock_device.get(), GetActiveConfiguration());
{
base::RunLoop loop;

Powered by Google App Engine
This is Rietveld 408576698